from setuptools import setup

setup(name='gauss_binom_probability',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gauss_binom_probability'],
      author = 'Oluchi Obi-Alago',
      author_email = 'ejindu.oluchukwu@gmail.com',
      zip_safe=False)
